@@ -12,21 +12,65 @@ import lxml.html
 from lxml.cssselect import CSSSelector
 from lxml.html.clean import Cleaner
 
-
-
 import requests
 
 class Scrape(BrowserView):
-    """   lxml    """
+    """   A View that uses lxml to embed external content    """
+    
+    def scraped(self):
+        #get settings from control panel
+        selector = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_selector')
+        scrape_base_url = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_base_url')    
+        url = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_url')
+        scrape_javascript = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_javascript')
+        scrape_style = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_style')
+        
+        if hasattr(self.request, 'url'):
+            url = self.request.url
+        
+        if hasattr(self.request, 'selector'):
+            parts = url.split('//', 1)
+            scrape_base_url = parts[0]+'//'+parts[1].split('/', 1)[0]
+        
+        parts = url.split('//', 1)
+        scrape_base_url = parts[0]+'//'+parts[1].split('/', 1)[0]
+        
+        
+        #get html from the requested url
+        r = requests.get(url)
+        tree = lxml.html.fromstring(r.text)
+             
+        #clean evil stuff
+        cleaner = Cleaner(javascript = scrape_javascript , style = scrape_style )
+        cleaner(tree)
+        
+        #the parsed DOM Tree
+        lxml.html.tostring(tree)
+
+        #relink
+        tree.make_links_absolute(scrape_base_url, resolve_base_href=True)
+        tree.rewrite_links(self.repl)
+        
+        # construct a CSS Selector
+        sel = CSSSelector(selector)
+        
+        
+        # Apply the selector to the DOM tree.
+        results = sel(tree)
+        
+        # the HTML for the first result.
+        if results:
+            match = results[0]
+            return lxml.html.tostring(match)
+
+        #return "Content can not be filtered, returning whole page"
+        return lxml.html.tostring(tree)
+        
     
     def repl(html, link):
-        selector = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_selector')
         scrape_base_url = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_base_url')
         root_url = api.portal.get().absolute_url()
         
-        #if link.startswidth('/'):
-        #    link = scrape_base_url + link
-        
         #open pages from other sites in its own window.
         if (not (link.startswith(scrape_base_url))):
             return link
@@ -36,113 +80,14 @@ class Scrape(BrowserView):
         #point other pages from same site to embedded view
         link =   root_url + '/scrape?url=' + link
         return link
-        
-    def scraped(self):
-        #get settings from control panel
-        selector = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_selector')
-        scrape_base_url = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_base_url')
-        
-        url = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_url')
-        
-        if hasattr(self.request, 'url'):
-            parts = url.split('//', 1)
-            scrape_base_url = parts[0]+'//'+parts[1].split('/', 1)[0]
-        
-            url = self.request.url
-        
-        
-        #get html from the requested url
-        r = requests.get(url)
-        tree = lxml.html.fromstring(r.text)
-        
-                
-        #clean evil stuff
-        cleaner = Cleaner(javascript = True , style = True )
-        cleaner(tree)
-        
-        #the parsed DOM Tree
-        lxml.html.tostring(tree)
-
-        
-        # construct a CSS Selector
-        sel = CSSSelector(selector)
-        
-        # Apply the selector to the DOM tree.
-        results = sel(tree)
-        
-        # the HTML for the first result.
-        if results:
-            match = results[0]
-            #relink
-            match.make_links_absolute(scrape_base_url, resolve_base_href=True)
-            match.rewrite_links(self.repl)
-        
-            return lxml.html.tostring(match)
-        #return "Content can not be filtered, we are returning whole page"
-        return lxml.html.tostring(tree)
 
 
 class ScrapeView(BrowserView):
-    """   A View that uses lxml to embed external content    """
+    """   A Dexterity Content View that redirects to the scrape view """
     
-    def repl(html, link):
-        selector = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_selector')
-        scrape_base_url = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_base_url')
-        
-        root_url = api.portal.get().absolute_url()
-
-        #if link.startswidth('/'):
-        #    link = scrape_base_url + link
-            
-        if (not (link.startswith(scrape_base_url))):
-            return link
-        if link.endswith('.jpg') or link.endswith('.png') or link.endswith('.gif') or link.endswith('.js') or link.endswith('.jpeg') or link.endswith('.pdf'):
-            return link
-        if link.startswidth(scrape_base_url):
-            link =   root_url + '/scrape?url=' + link
+    def __call__(self):
+    	root_url = api.portal.get().absolute_url()
+    	self.request.response.redirect(root_url + "/scrape?url=" + self.context.scrape_url + "&selector=" + self.context.scrape_selector)
 
         
-        return link
-    
-    @property
-    def scraped(self):
-        url=self.context.scrape_url
-        selector = self.context.scrape_selector
-        
-        #scrape_base_url = api.portal.get_registry_record('medialog.mobilethemeTwo.interfaces.IMobilethemeTwoSettings.scrape_base_url')
-         
-        #get html from the requested url
-        r = requests.get(url)
- 
-        tree = lxml.html.fromstring(r.text)
-        
-                
-        #clean evil stuff
-        cleaner = Cleaner(javascript = True , style = True )
-        cleaner(tree)
-        
-        #the parsed DOM Tree
-        lxml.html.tostring(tree)
-
-        
-        # construct a CSS Selector
-        sel = CSSSelector(selector)
-        
-        # Apply the selector to the DOM tree.
-        results = sel(tree)
-        
-        parts = url.split('//', 1)
-        scrape_base_url = parts[0]+'//'+parts[1].split('/', 1)[0]
-        
-        # the HTML for the first result.
-        if results:
-            match = results[0]
-            #clean evil stuff
-            #relink
-            match.make_links_absolute(scrape_base_url, resolve_base_href=True)
-            match.rewrite_links(self.repl)
-            
-            return lxml.html.tostring(match)
-            
-        #return "Content can not be shown"
-        return lxml.html.tostring(tree)
\ No newline at end of file
+         
\ No newline at end of file
